import { Signature } from '@shardeum-foundation/lib-crypto-utils';
interface WrappedData {
    /** Account ID */
    accountId: string;
    /** hash of the data blob */
    stateId: string;
    /** data blob opaqe */
    data: unknown;
    /** Timestamp */
    timestamp: number;
    /** optional data related to sync process */
    syncData?: unknown;
}
type WrappedStateArray = WrappedData[];
type GetAccountDataByRangeSmart = {
    wrappedAccounts: WrappedStateArray;
    lastUpdateNeeded: boolean;
    wrappedAccounts2: WrappedStateArray;
    highestTs: number;
    delta: number;
};
type GlobalAccountReportResp = {
    ready: boolean;
    combinedHash: string;
    accounts: {
        id: string;
        hash: string;
        timestamp: number;
    }[];
};
export interface AccountDataRequestSchema {
    accountStart: string;
    accountEnd: string;
    tsStart: number;
    maxRecords: number;
    offset: number;
    accountOffset: string;
    sign: Signature;
}
export interface AccountDataByListRequestSchema {
    accountIds: string[];
    sign: Signature;
}
export interface GlobalAccountReportRequestSchema {
    sign: Signature;
}
export declare const servingValidators: Map<string, number>;
export declare const validateAccountDataRequest: (payload: AccountDataRequestSchema) => {
    success: boolean;
    error?: string;
};
export declare const validateAccountDataByListRequest: (payload: AccountDataByListRequestSchema) => {
    success: boolean;
    error?: string;
};
export declare const validateGlobalAccountReportRequest: (payload: GlobalAccountReportRequestSchema) => {
    success: boolean;
    error?: string;
};
/**
 *
 * This function is contructed to provide data in similar way as the `getAccountDataByRangeSmart` function in the validator
 * @param payload
 * @returns GetAccountDataByRangeSmart
 */
export declare const provideAccountDataRequest: (payload: AccountDataRequestSchema) => Promise<GetAccountDataByRangeSmart>;
export declare const provideAccountDataByListRequest: (payload: AccountDataByListRequestSchema) => Promise<WrappedStateArray>;
export declare const provideGlobalAccountReportRequest: () => Promise<GlobalAccountReportResp>;
export declare const clearServingValidatorsInterval: () => void;
export declare const initServingValidatorsInterval: () => void;
export {};
