"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.closeDatabase = exports.initializeDB = exports.processedTxDatabase = exports.originalTxDataDatabase = exports.receiptDatabase = exports.transactionDatabase = exports.accountDatabase = exports.cycleDatabase = void 0;
const sqlite3storage_1 = require("./sqlite3storage");
const Utils_1 = require("../Utils");
const initializeDB = async (config) => {
    (0, Utils_1.createDirectories)(config.ARCHIVER_DB);
    exports.accountDatabase = await (0, sqlite3storage_1.createDB)(`${config.ARCHIVER_DB}/${config.ARCHIVER_DATA.accountDB}`, 'Account');
    exports.cycleDatabase = await (0, sqlite3storage_1.createDB)(`${config.ARCHIVER_DB}/${config.ARCHIVER_DATA.cycleDB}`, 'Cycle');
    exports.transactionDatabase = await (0, sqlite3storage_1.createDB)(`${config.ARCHIVER_DB}/${config.ARCHIVER_DATA.transactionDB}`, 'Transaction');
    exports.receiptDatabase = await (0, sqlite3storage_1.createDB)(`${config.ARCHIVER_DB}/${config.ARCHIVER_DATA.receiptDB}`, 'Receipt');
    exports.originalTxDataDatabase = await (0, sqlite3storage_1.createDB)(`${config.ARCHIVER_DB}/${config.ARCHIVER_DATA.originalTxDataDB}`, 'OriginalTxData');
    exports.processedTxDatabase = await (0, sqlite3storage_1.createDB)(`${config.ARCHIVER_DB}/${config.ARCHIVER_DATA.processedTxDB}`, 'ProcessedTransaction');
    await (0, sqlite3storage_1.runCreate)(exports.transactionDatabase, 'CREATE TABLE if not exists `transactions` (`txId` TEXT NOT NULL UNIQUE PRIMARY KEY, `appReceiptId` TEXT, `timestamp` BIGINT NOT NULL, `cycleNumber` NUMBER NOT NULL, `data` JSON NOT NULL, `originalTxData` JSON NOT NULL)');
    await (0, sqlite3storage_1.runCreate)(exports.transactionDatabase, 'CREATE INDEX if not exists `transactions_timestamp` ON `transactions` (`timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.transactionDatabase, 'CREATE INDEX if not exists `transactions_cycleNumber_timestamp` ON `transactions` (`cycleNumber` ASC, `timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.transactionDatabase, 'CREATE INDEX if not exists `transactions_appReceiptId_idx` ON `transactions` (`appReceiptId`)');
    await (0, sqlite3storage_1.runCreate)(exports.cycleDatabase, 'CREATE TABLE if not exists `cycles` (`cycleMarker` TEXT NOT NULL UNIQUE PRIMARY KEY, `counter` NUMBER NOT NULL, `cycleRecord` JSON NOT NULL)');
    await (0, sqlite3storage_1.runCreate)(exports.cycleDatabase, 'CREATE INDEX if not exists `cycles_idx` ON `cycles` (`counter` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.accountDatabase, 'CREATE TABLE if not exists `accounts` (`accountId` TEXT NOT NULL UNIQUE PRIMARY KEY, `data` JSON NOT NULL, `timestamp` BIGINT NOT NULL, `hash` TEXT NOT NULL, `cycleNumber` NUMBER NOT NULL, `isGlobal` BOOLEAN NOT NULL)');
    await (0, sqlite3storage_1.runCreate)(exports.accountDatabase, 'CREATE INDEX if not exists `accounts_cycleNumber` ON `accounts` (`cycleNumber` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.accountDatabase, 'CREATE INDEX if not exists `accounts_timestamp` ON `accounts` (`timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.accountDatabase, 'CREATE INDEX if not exists `accounts_cycleNumber_timestamp` ON `accounts` (`cycleNumber` ASC, `timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.receiptDatabase, 'CREATE TABLE if not exists `receipts` (`receiptId` TEXT NOT NULL UNIQUE PRIMARY KEY, `tx` JSON NOT NULL, `cycle` NUMBER NOT NULL, `applyTimestamp` BIGINT NOT NULL, `timestamp` BIGINT NOT NULL, `signedReceipt` JSON NOT NULL, `afterStates` JSON, `beforeStates` JSON, `appReceiptData` JSON, `executionShardKey` TEXT NOT NULL, `globalModification` BOOLEAN NOT NULL)');
    await (0, sqlite3storage_1.runCreate)(exports.receiptDatabase, 'CREATE INDEX if not exists `receipts_cycle` ON `receipts` (`cycle` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.receiptDatabase, 'CREATE INDEX if not exists `receipts_timestamp` ON `receipts` (`timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.receiptDatabase, 'CREATE INDEX if not exists `receipts_cycle` ON `receipts` (`cycle` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.receiptDatabase, 'CREATE INDEX if not exists `receipts_cycle_timestamp` ON `receipts` (`cycle` ASC, `timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.originalTxDataDatabase, 'CREATE TABLE if not exists `originalTxsData` (`txId` TEXT NOT NULL, `timestamp` BIGINT NOT NULL, `cycle` NUMBER NOT NULL, `originalTxData` JSON NOT NULL, PRIMARY KEY (`txId`, `timestamp`))');
    await (0, sqlite3storage_1.runCreate)(exports.originalTxDataDatabase, 'CREATE INDEX if not exists `originalTxsData_cycle` ON `originalTxsData` (`cycle` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.originalTxDataDatabase, 'CREATE INDEX if not exists `originalTxsData_timestamp` ON `originalTxsData` (`timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.originalTxDataDatabase, 'CREATE INDEX if not exists `originalTxsData_cycle_timestamp` ON `originalTxsData` (`cycle` ASC, `timestamp` ASC)');
    await (0, sqlite3storage_1.runCreate)(exports.originalTxDataDatabase, 'CREATE INDEX if not exists `originalTxsData_txId` ON `originalTxsData` (`txId`)');
    // Transaction digester service tables
    await (0, sqlite3storage_1.runCreate)(exports.processedTxDatabase, 'CREATE TABLE if not exists `processedTxs` (`txId` VARCHAR(128) NOT NULL, `cycle` BIGINT NOT NULL, `txTimestamp` BIGINT NOT NULL, `applyTimestamp` BIGINT NOT NULL, PRIMARY KEY (`txId`))');
    await (0, sqlite3storage_1.runCreate)(exports.processedTxDatabase, 'CREATE INDEX if not exists `processedTxs_cycle_idx` ON `processedTxs` (`cycle`)');
};
exports.initializeDB = initializeDB;
const closeDatabase = async () => {
    const promises = [];
    promises.push((0, sqlite3storage_1.close)(exports.accountDatabase, 'Account'));
    promises.push((0, sqlite3storage_1.close)(exports.transactionDatabase, 'Transaction'));
    promises.push((0, sqlite3storage_1.close)(exports.cycleDatabase, 'Cycle'));
    promises.push((0, sqlite3storage_1.close)(exports.receiptDatabase, 'Receipt'));
    promises.push((0, sqlite3storage_1.close)(exports.originalTxDataDatabase, 'OriginalTxData'));
    promises.push((0, sqlite3storage_1.close)(exports.processedTxDatabase, 'ProcessedTransaction'));
    await Promise.all(promises);
};
exports.closeDatabase = closeDatabase;
//# sourceMappingURL=index.js.map