import { Signature } from '@shardeum-foundation/lib-crypto-utils';
import { P2P } from '@shardeum-foundation/lib-types';
import { AccountsCopy } from '../dbstore/accounts';
export type Proposal = {
    applied: boolean;
    cant_preApply: boolean;
    accountIDs: string[];
    beforeStateHashes: string[];
    afterStateHashes: string[];
    appReceiptDataHash: string;
    txid: string;
};
export type SignedReceipt = {
    proposal: Proposal;
    proposalHash: string;
    signaturePack: Signature[];
    voteOffsets: number[];
    sign?: Signature;
};
/**
 * ArchiverReceipt is the full data (shardusReceipt + appReceiptData + accounts ) of a tx that is sent to the archiver
 */
export interface ArchiverReceipt {
    tx: {
        originalTxData: object;
        txId: string;
        timestamp: number;
    };
    cycle: number;
    signedReceipt: SignedReceipt | P2P.GlobalAccountsTypes.GlobalTxReceipt;
    afterStates?: AccountsCopy[];
    beforeStates?: AccountsCopy[];
    appReceiptData: object & {
        accountId?: string;
        data: object;
        [key: string]: any;
    };
    executionShardKey: string;
    globalModification: boolean;
}
export type AppliedVote = {
    txid: string;
    transaction_result: boolean;
    account_id: string[];
    account_state_hash_after: string[];
    account_state_hash_before: string[];
    cant_apply: boolean;
    node_id: string;
    sign: Signature;
    app_data_hash: string;
};
/**
 * a space efficent version of the receipt
 *
 * use TellSignedVoteHash to send just signatures of the vote hash (votes must have a deterministic sort now)
 * never have to send or request votes individually, should be able to rely on existing receipt send/request
 * for nodes that match what is required.
 */
export type ConfirmOrChallengeMessage = {
    message: string;
    nodeId: string;
    appliedVote: AppliedVote;
    sign: Signature;
};
export interface Receipt extends ArchiverReceipt {
    receiptId: string;
    timestamp: number;
    applyTimestamp: number;
}
export interface ReceiptCount {
    cycle: number;
    receiptCount: number;
}
export declare function insertReceipt(receipt: Receipt): Promise<void>;
export declare function bulkInsertReceipts(receipts: Receipt[]): Promise<void>;
export declare function queryReceiptByReceiptId(receiptId: string, timestamp?: number): Promise<Receipt>;
export declare function queryLatestReceipts(count: number): Promise<Receipt[]>;
export declare function queryReceipts(skip?: number, limit?: number): Promise<Receipt[]>;
export declare function queryReceiptCount(): Promise<number>;
export declare function queryReceiptCountByCycles(start: number, end: number): Promise<ReceiptCount[]>;
export declare function queryReceiptCountBetweenCycles(startCycleNumber: number, endCycleNumber: number): Promise<number>;
export declare function queryReceiptsBetweenCycles(skip: number, limit: number, startCycleNumber: number, endCycleNumber: number): Promise<Receipt[]>;
